%==========================================================================
% El modelo y Gdelta
%==========================================================================

load modelo

% El modelo que se carga corresponde a lo de clase con los parmetros
% Jm = 0.423;
% Jl = 0.70425;
% Ks = 372;
% bm = 1.2;
% bs = 0.12;
%
% Noten que Go, G y Gdelta estn en variables de estado.  Se convierte a
% funcin de transferencia usando comandos "zpk" o "tf"
%

[x,xx,w]=bode(G);  % ejecuten "help bode"
[mG, fG]=bode(G,w);
[mGo, fGo]=bode(Go,w);
[mGdelta, fGdelta]=bode(Gdelta,w);

mG = squeeze(mG);  % "maas" del comando "bode"
fG = squeeze(fG);
mGo = squeeze(mGo);
fGo = squeeze(fGo);
mGdelta = squeeze(mGdelta);
fGdelta = squeeze(fGdelta);

figure
subplot(2,1,1), semilogx(w, 20*log10(mG), 'k', 'LineWidth',2), hold on, plot(w, 20*log10(mGo), 'k--', 'LineWidth',2), grid on
ylabel('Magnitud [dB]')
subplot(2,1,2), semilogx(w, fG, 'k',  'LineWidth',2), hold on, plot(w, fGo, 'k--', 'LineWidth',2), grid on
xlabel('Frequencia [rad/s]')
ylabel('Fase [deg]')
subplot(2,1,1), hold on, semilogx(w, 20*log10(mGdelta), 'r',  'LineWidth',2)
subplot(2,1,2), hold on, semilogx(w, fGdelta, 'r',  'LineWidth',2)
subplot(2,1,1), legend('G (j\omega)', 'G_o (j\omega)', 'G_{\Delta} (j\omega)')
subplot(2,1,2), legend('G (j\omega)', 'G_o (j\omega)', 'G_{\Delta} (j\omega)')

%==========================================================================
% Gdelta versus distintas elecciones de To
%==========================================================================

load controladores

% Se cargan los cuatro controladores de clase (C1, ..., C4) y las cuatro funciones 
% de sensibilidad complementaria NOMINALES y REALES correspondientes (To1, T1, ..., To4, T4).  De nuevo, 
% todo est en variables de estado.
%

w = logspace(-1, 3, 5000);              
[mGdelta, wGdelta] = sigma(Gdelta,w);  % sigma entrega slo la magnitud de un sistema
[mTo1, wTo] = sigma( To1, w );
[mTo2, wTo] = sigma( To2, w );
[mTo3, wTo] = sigma( To3, w );
[mTo4, wTo] = sigma( To4, w );

figure
semilogx(wGdelta, -20*log10(mGdelta),'k', 'Linewidth',2), hold on
semilogx(wTo, 20*log10(mTo1), 'k', 'Linewidth',1)
semilogx(wTo, 20*log10(mTo2), 'k--', 'Linewidth',2)
semilogx(wTo, 20*log10(mTo3), 'b', 'Linewidth',2)
semilogx(wTo, 20*log10(mTo4), 'b--', 'Linewidth',2)
semilogx(wTo, 0*ones(size(wTo)), 'r', 'Linewidth',2)
grid on
xlabel('Frequencia [rad/s]')
ylabel('Magnitud [dB]')
legend('| G_{\Delta} (j\omega) |^{-1}', 'T_{o1} (j\omega)', 'T_{o2} (j\omega)', 'T_{o3} (j\omega)', 'T_{o4} (j\omega)')

%==========================================================================
% Simulaciones
%==========================================================================

t=[0:1e-3:10];

[yo,t]= step( [To1 To2 To3 To4], t); % respuestas a escaln nominales.
[y,t]= step( [T1 T2 T3 T4], t);      % respuestas a escaln reales.

figure
subplot(2,2,1), plot(t, y(:,1,1), 'k', 'Linewidth',1), hold on, grid on
subplot(2,2,1), plot(t, yo(:,1,1), 'g', 'Linewidth',2)
xlabel('tiempo [s]'), ylabel('\theta_L [rad]'), title('Caso 1'), legend('Real', 'Nominal')
subplot(2,2,2), plot(t, y(:,1,2), 'k', 'Linewidth',1), hold on, grid on
subplot(2,2,2), plot(t, yo(:,1,2), 'g', 'Linewidth',2)
xlabel('tiempo [s]'), ylabel('\theta_L [rad]'), title('Caso 2'), legend('Real', 'Nominal')
subplot(2,2,3), plot(t, y(:,1,3), 'k', 'Linewidth',1), hold on, grid on
subplot(2,2,3), plot(t, yo(:,1,3), 'g', 'Linewidth',2)
xlabel('tiempo [s]'), ylabel('\theta_L [rad]'), title('Caso 3'), legend('Real', 'Nominal')
subplot(2,2,4), plot(t, y(:,1,4), 'k', 'Linewidth',1), hold on, grid on
subplot(2,2,4), plot(t, yo(:,1,4), 'g', 'Linewidth',2)
xlabel('tiempo [s]'), ylabel('\theta_L [rad]'), title('Caso 4'), legend('Real', 'Nominal')

